==> huaweicloudsdkiam-3.0.81-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_list_federation_domains_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KeystoneListFederationDomainsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domains': 'list[Domains]',
        'links': 'LinksSelf'
    }

    attribute_map = {
        'domains': 'domains',
        'links': 'links'
    }

    def __init__(self, domains=None, links=None):
        """KeystoneListFederationDomainsResponse - a model defined in huaweicloud sdk"""
        
        super(KeystoneListFederationDomainsResponse, self).__init__()

        self._domains = None
        self._links = None
        self.discriminator = None

        if domains is not None:
            self.domains = domains
        if links is not None:
            self.links = links

    @property
    def domains(self):
        """Gets the domains of this KeystoneListFederationDomainsResponse.

        账号信息列表。

        :return: The domains of this KeystoneListFederationDomainsResponse.
        :rtype: list[Domains]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this KeystoneListFederationDomainsResponse.

        账号信息列表。

        :param domains: The domains of this KeystoneListFederationDomainsResponse.
        :type: list[Domains]
        """
        self._domains = domains

    @property
    def links(self):
        """Gets the links of this KeystoneListFederationDomainsResponse.


        :return: The links of this KeystoneListFederationDomainsResponse.
        :rtype: LinksSelf
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this KeystoneListFederationDomainsResponse.


        :param links: The links of this KeystoneListFederationDomainsResponse.
        :type: LinksSelf
        """
        self._links = links

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneListFederationDomainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.102-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_list_federation_domains_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KeystoneListFederationDomainsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domains': 'list[Domains]',
        'links': 'LinksSelf'
    }

    attribute_map = {
        'domains': 'domains',
        'links': 'links'
    }

    def __init__(self, domains=None, links=None):
        """KeystoneListFederationDomainsResponse

        The model defined in huaweicloud sdk

        :param domains: 账号信息列表。
        :type domains: list[:class:`huaweicloudsdkiam.v3.Domains`]
        :param links: 
        :type links: :class:`huaweicloudsdkiam.v3.LinksSelf`
        """
        
        super(KeystoneListFederationDomainsResponse, self).__init__()

        self._domains = None
        self._links = None
        self.discriminator = None

        if domains is not None:
            self.domains = domains
        if links is not None:
            self.links = links

    @property
    def domains(self):
        """Gets the domains of this KeystoneListFederationDomainsResponse.

        账号信息列表。

        :return: The domains of this KeystoneListFederationDomainsResponse.
        :rtype: list[:class:`huaweicloudsdkiam.v3.Domains`]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this KeystoneListFederationDomainsResponse.

        账号信息列表。

        :param domains: The domains of this KeystoneListFederationDomainsResponse.
        :type domains: list[:class:`huaweicloudsdkiam.v3.Domains`]
        """
        self._domains = domains

    @property
    def links(self):
        """Gets the links of this KeystoneListFederationDomainsResponse.


        :return: The links of this KeystoneListFederationDomainsResponse.
        :rtype: :class:`huaweicloudsdkiam.v3.LinksSelf`
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this KeystoneListFederationDomainsResponse.


        :param links: The links of this KeystoneListFederationDomainsResponse.
        :type links: :class:`huaweicloudsdkiam.v3.LinksSelf`
        """
        self._links = links

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneListFederationDomainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
